@@ -5,5 +5,6 @@ from .selfpaint_btn import (  # noqa
     HomeButton, LeftArrowButton, RightArrowButton, SearchButton, SettingsButton,
     PlusButton, TriagleButton, DiscoveryButton,
     SelfPaintAbstractIconTextButton, CalendarButton, RankButton,
-    StarButton,
+    StarButton, PlayPauseButton, PlayNextButton, PlayPreviousButton,
+    MVButton, VolumeButton,
 )
