@@ -16,27 +16,35 @@ from feeluown.utils.reader import wrap as reader_wrap
 logger = logging.getLogger(__name__)
 
 
+def win32_is_port_binded(host, port):
+    """
+    sock.connect_ex may block for 2 second if port is not used on Windows.
+    This may be the fastest way to check if a port is bined on Windows.
+    Remember that (127.0.0.1, port) and (0.0.0.0, port) are different for `sock.bind`.
+    """
+    import errno  # pylint: disable=import-outside-toplevel
+
+    inuse = False
+    sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
+    try:
+        sock.bind((host, port))
+    except socket.error as e:
+        if e.errno == errno.EADDRINUSE:
+            inuse = True
+        else:
+            raise
+    finally:
+        sock.close()
+    return inuse
+
+
 def is_port_inuse(port):
     sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
-    # TODO: this may block for 2 second if port is not used on Windows
     rv = sock.connect_ex(('127.0.0.1', port))
     sock.close()
     return rv == 0
 
 
-def use_mpv_old():
-    try:
-        import mpv  # noqa
-    except AttributeError as e:
-        # libmpv<1.28 'undefined symbol: mpv_render_context_create'
-        # libmpv<1.29 'undefined symbol: mpv_destroy'
-        msg = str(e)
-        if 'undefined symbol' in msg:
-            logger.info(f'use mpv old because of err: {msg}')
-            return True
-    return False
-
-
 def parse_ms(ms):
     minute = int(ms / 60000)
     second = int((ms % 60000) / 1000)
@@ -75,35 +83,6 @@ def elfhash(s):
     return (hash & 0x7FFFFFFF)
 
 
-def find_previous(element, list_):
-    """
-    find previous element in a sorted list
-
-    >>> find_previous(0, [0])
-    0
-    >>> find_previous(2, [1, 1, 3])
-    1
-    >>> find_previous(0, [1, 2])
-    >>> find_previous(1.5, [1, 2])
-    1
-    >>> find_previous(3, [1, 2])
-    2
-    """
-    length = len(list_)
-    for index, current in enumerate(list_):
-        # current is the last element
-        if length - 1 == index:
-            return current
-
-        # current is the first element
-        if index == 0:
-            if element < current:
-                return None
-
-        if current <= element < list_[index+1]:
-            return current
-
-
 def get_osx_theme():
     """1 for dark, -1 for light"""
     with os.popen('defaults read -g AppleInterfaceStyle') as pipe:
